@@ -282,7 +282,7 @@ class TeX:
 
         tmp = self.main.split("\n")
         for i in range(len(tmp)):
-            tmp[i] = re.sub(r"([^%]*)(%)(.*)$", r"\1", tmp[i])
+            tmp[i] = re.sub(r"([^%]*)(?<!\\)(%)(.*)$", r"\1", tmp[i])
         self.main = "\n".join(tmp)
 
     def _replace_command_impl(self, cmd: str, nargs: int, replace: str):
@@ -605,7 +605,7 @@ class TeX:
 
             for h in headers:
                 test = ilab > headers[h]
-                i = test.size - 1 if np.all(test) else np.argmin(test)
+                i = test.size - 1 if np.all(test) else np.argmin(test) - 1
                 start = headers[h][i] + 1
                 if re.match(r"([\s\n%]*)(\\label{)", self.main[start:]):
                     change[label] = self._reformat(label, iden[h])
@@ -622,7 +622,17 @@ class TeX:
 
     def use_cleveref(self):
         """
-        Replace ``Eq.~\\eqref{...}``, ``Fig.~\ref{...}``, etc. for ``\\cref{...}``.
+        Replace::
+
+            Eq.~\\eqref{...}
+            Fig.~\\ref{...}
+            ...
+
+        By::
+
+            \\cref{...}
+
+        everywhere.
         """
 
         for key in ["Figure", "Fig.", "Table", "Tab.", "Chapter", "Ch.", "Section", "Sec."]:
